.. Sphinx modern PDF style documentation master file, created by
   sphinx-quickstart on Wed Jul 16 21:58:36 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Sphinx modern PDF style's documentation!
===================================================

This is a test!

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
